@@ -1237,14 +1237,14 @@ integer n:    Retrieve n pages of header indices.")
       (concat "<div align=\"left\">\n--&nbsp;<br>\n$B$3$N5-;v$NCx:n8"$O!"(B"
 	      (shimbun-server-name shimbun)
 	      "$B<R$K5"B0$7$^$9!#(B<br>\n$B86J*$O(B <a href=\""
-	      (shimbun-article-base-url shimbun header) "\">"
+	      (shimbun-article-base-url shimbun header) "\">&lt;"
 	      (shimbun-article-base-url shimbun header)
-	      "</a> $B$G8x3+$5$l$F$$$^$9!#(B\n</div>\n")
+	      "&gt;</a> $B$G8x3+$5$l$F$$$^$9!#(B\n</div>\n")
     (concat "-- \n$B$3$N5-;v$NCx:n8"$O!"(B"
 	    (shimbun-server-name shimbun)
-	    "$B<R$K5"B0$7$^$9!#(B\n$B86J*$O(B "
+	    "$B<R$K5"B0$7$^$9!#(B\n$B86J*$O(B <"
 	    (shimbun-article-base-url shimbun header)
-	    " $B$G8x3+$5$l$F$$$^$9!#(B\n")))
+	    "> $B$G8x3+$5$l$F$$$^$9!#(B\n")))
 
 ;;; Misc Functions
 (defun shimbun-header-insert-and-buffer-string (shimbun header
